<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>AboutBox</name>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="33"/>
        <source>About Q Light Controller Plus</source>
        <translation>Quant a Q Light Controller Plus</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="88"/>
        <source>Contributors</source>
        <translation>Col·laboradors</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.ui" line="135"/>
        <source>This application is licensed under the terms of the Apache 2.0 license.</source>
        <translation>Aquesta aplicació està llicenciada sota els termes de la llicència Apache 2.0.</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="42"/>
        <source>and contributors:</source>
        <translation>i col·laboradors:</translation>
    </message>
    <message>
        <location filename="../ui/src/aboutbox.cpp" line="43"/>
        <source>Website: %1</source>
        <translation>Websita: %1</translation>
    </message>
</context>
<context>
    <name>AddChannelsDialog</name>
    <message>
        <location filename="addchannelsdialog.ui" line="33"/>
        <source>Fixture Mode Channels Editor</source>
        <translation>Editor de Canals del Mode del Fixture</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="114"/>
        <source>Available channels</source>
        <translation>Canals disponibles</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="106"/>
        <location filename="addchannelsdialog.ui" line="135"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="121"/>
        <source>Mode channels</source>
        <translation>Canals del mode</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="app.cpp" line="122"/>
        <source>Unrecognized file extension: %1</source>
        <translation>Extensió d&apos;arxiu desconeguda: %1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="146"/>
        <source>Fixture loading failed</source>
        <translation>Error al carregar el Fixture</translation>
    </message>
    <message>
        <location filename="app.cpp" line="147"/>
        <source>Unable to load fixture definition: </source>
        <translation>No es pot carregar la definició del fixture: </translation>
    </message>
    <message>
        <location filename="app.cpp" line="241"/>
        <source>&amp;New</source>
        <translation>&amp;Nou</translation>
    </message>
    <message>
        <location filename="app.cpp" line="242"/>
        <source>CTRL+N</source>
        <comment>File|New</comment>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <location filename="app.cpp" line="247"/>
        <source>&amp;Open</source>
        <translation>&amp;Obrir</translation>
    </message>
    <message>
        <location filename="app.cpp" line="248"/>
        <source>CTRL+O</source>
        <comment>File|Open</comment>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <location filename="app.cpp" line="253"/>
        <source>&amp;Save</source>
        <translation>&amp;Desar</translation>
    </message>
    <message>
        <location filename="app.cpp" line="254"/>
        <source>CTRL+S</source>
        <comment>File|Save</comment>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="259"/>
        <source>Save &amp;As...</source>
        <translation>Desar &amp;com...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="260"/>
        <source>CTRL+SHIFT+S</source>
        <comment>File|Save As...</comment>
        <translation>CTRL+SHIFT+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="265"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sortir</translation>
    </message>
    <message>
        <location filename="app.cpp" line="266"/>
        <source>CTRL+Q</source>
        <comment>File|Quit</comment>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <location filename="app.cpp" line="272"/>
        <source>Index</source>
        <translation>Índex</translation>
    </message>
    <message>
        <location filename="app.cpp" line="273"/>
        <source>SHIFT+F1</source>
        <comment>Help|Index</comment>
        <translation>SHIFT+F1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="278"/>
        <source>About Fixture Definition Editor...</source>
        <translation>Quant a l&apos;Editor de definicions de Fixture...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="283"/>
        <source>About Qt...</source>
        <translation>Quant a QT...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="310"/>
        <source>&amp;File</source>
        <translation>&amp;Arxiu</translation>
    </message>
    <message>
        <location filename="app.cpp" line="320"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="app.cpp" line="358"/>
        <source>Open a fixture definition</source>
        <translation>Obrir una definició de fixture</translation>
    </message>
</context>
<context>
    <name>CapabilityWizard</name>
    <message>
        <location filename="capabilitywizard.ui" line="33"/>
        <source>Capability Wizard</source>
        <translation>Assistent de Capacitats</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="39"/>
        <source>Values</source>
        <translation>Valors</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="45"/>
        <source>Start</source>
        <translation>Inici</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="52"/>
        <source>The starting DMX value</source>
        <translation>Valor DMX inicial</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="62"/>
        <source>Width</source>
        <translation>Ample</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="69"/>
        <source>Number of values per capability</source>
        <translation>Nombre de valors per capacitat</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="85"/>
        <source>Amount</source>
        <translation>Quantitat</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="92"/>
        <source>Number of capabilities to create</source>
        <translation>Nombre de capacitats a crear</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="108"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="114"/>
        <source>The common base name for all capabilities. Use hash &apos;#&apos; to create a running number.</source>
        <translation>El nom comú per totres les capacitats. Utilitzi coixinet (#) per crear nombres consecutius.</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="117"/>
        <source>Capability #</source>
        <translation># Capacitats</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="127"/>
        <source>Sample</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="133"/>
        <source>A list of capabilities that would be created with these settings</source>
        <translation>Llista de capacitats que seràn creades amb aquests paràmetres</translation>
    </message>
</context>
<context>
    <name>DocBrowser</name>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="106"/>
        <source>%1 - Document Browser</source>
        <translation>%1 - Cercador de documents</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="128"/>
        <source>Backward</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="129"/>
        <source>Forward</source>
        <translation>Endavant</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="130"/>
        <source>Index</source>
        <translation>Índex</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="131"/>
        <source>About Qt</source>
        <translation>Quant a QT</translation>
    </message>
    <message>
        <location filename="../ui/src/docbrowser.cpp" line="132"/>
        <source>Close this window</source>
        <translation>Tanca aquesta finestra</translation>
    </message>
</context>
<context>
    <name>EditChannel</name>
    <message>
        <location filename="editchannel.ui" line="33"/>
        <source>Edit Channel</source>
        <translation>Editor de Canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="114"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Capability overlapping detected. Please fix.&lt;/b&gt;&lt;/font&gt;</source>
        <translation>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;S&apos;ha detectat una superposició de capacitats. Siu us plau corregiu-ho.&lt;/b&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="198"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="240"/>
        <source>Default value</source>
        <translation>Valor per defecte</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="253"/>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="260"/>
        <location filename="editchannel.ui" line="303"/>
        <source>Preset</source>
        <translation>Preset</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="267"/>
        <source>The name of this channel</source>
        <translation>Nom d&apos;aquest canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="274"/>
        <source>Role</source>
        <translation>Rol</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="336"/>
        <source>Color 1</source>
        <translation>Color 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="360"/>
        <source>Color 2</source>
        <translation>Color 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="387"/>
        <source>Value 1</source>
        <translation>Valor 1</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="401"/>
        <source>Value 2</source>
        <translation>Valor 2</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="430"/>
        <source>Preview</source>
        <translation>Vista Prèvia</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="227"/>
        <source>The group this channel belongs to</source>
        <translation>El grup al que pertany aquest canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="322"/>
        <source>Picture</source>
        <translation>Imatge</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="283"/>
        <source>Coarse (MSB)</source>
        <translation>Gruix (MSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="290"/>
        <source>Fine (LSB)</source>
        <translation>Fi (LSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="55"/>
        <source>Capabilities</source>
        <translation>Capacitats</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="90"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Minimum value</source>
        <translation>Valor Mínim</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="95"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Maximum value</source>
        <translation>Valor Màxim</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="100"/>
        <location filename="editchannel.cpp" line="572"/>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="154"/>
        <source>Remove the selected capability</source>
        <translation>Treure la capacitat seleccionada</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="121"/>
        <source>Capability wizard</source>
        <translation>Asistent de Capacitats</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="93"/>
        <source>Edit Channel: </source>
        <translation>Editar Canal: </translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="481"/>
        <source>Overlapping values</source>
        <translation>Superposició de Valors</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="498"/>
        <source>Open Gobo File</source>
        <translation>Obrir arxiu de Gobo</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="501"/>
        <source>Gobo pictures</source>
        <translation>Imatges de gobo</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="615"/>
        <source>Missing resources</source>
        <translation>Recursos que falten</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="616"/>
        <source>Some gobos are missing:

</source>
        <translation>Alguns gobos falten:

</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="482"/>
        <source>Some capabilities could not be created because of overlapping values.</source>
        <translation>Algunes capacitats no poden ser creades degut a una superposició de valors.</translation>
    </message>
</context>
<context>
    <name>EditHead</name>
    <message>
        <location filename="edithead.ui" line="33"/>
        <source>Edit Head</source>
        <translation>Editar Capçal</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="52"/>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="57"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>EditMode</name>
    <message>
        <location filename="editmode.ui" line="33"/>
        <source>Edit Mode</source>
        <translation>Editor de Mode</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="39"/>
        <source>Mode Name</source>
        <translation>Nom del Mode</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="53"/>
        <source>Channels</source>
        <translation>Canals</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="161"/>
        <source>Number</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="166"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="79"/>
        <source>Add channel(s) to this mode</source>
        <translation>Afegir canal(s) a aques mode</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="59"/>
        <source>Remove the selected channel</source>
        <translation>Treure el canal seleccionat</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="99"/>
        <source>Raise the selected channel</source>
        <translation>Pujar el canal seleccionat</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="119"/>
        <source>Lower the selected channel</source>
        <translation>Baixar el canal seleccionat</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="171"/>
        <source>Acts On</source>
        <translation>Actua Sobre</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="193"/>
        <source>Heads</source>
        <translation>Capçals</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="206"/>
        <source>Head</source>
        <translation>Capçal</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="214"/>
        <source>Compose a new head</source>
        <translation>Compondre un nou capçal</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="234"/>
        <source>Remove the selected head</source>
        <translation>Treure el capçal seleccionat</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="254"/>
        <source>Edit the channels that belong to the selected head</source>
        <translation>Editar els canals que pertanyen al capçal seleccionat</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="274"/>
        <source>Raise the selected head</source>
        <translation>Pujar el capçal sleccionat</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="294"/>
        <source>Lower the selected head</source>
        <translation>Baixar el capçal seleccionat</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="328"/>
        <source>Physical</source>
        <translation>Físic</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="338"/>
        <source>Use global settings</source>
        <translation>Usa ajustos globals</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="348"/>
        <source>Override global settings</source>
        <translation>Sobreescriu la configuració global</translation>
    </message>
</context>
<context>
    <name>EditPhysical</name>
    <message>
        <location filename="editphysical.ui" line="277"/>
        <source>Bulb</source>
        <translation>Bombeta</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="45"/>
        <location filename="editphysical.ui" line="283"/>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="515"/>
        <source>Lumens</source>
        <translation>Lúmens</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="535"/>
        <source>Colour Temp (K)</source>
        <translation>Temperatura de Color (K)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="708"/>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="784"/>
        <source>Weight</source>
        <translation>Pes</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="714"/>
        <source>kg</source>
        <translation>kg</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="724"/>
        <source>Width</source>
        <translation>Ample</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="734"/>
        <location filename="editphysical.ui" line="754"/>
        <location filename="editphysical.ui" line="774"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="744"/>
        <source>Height</source>
        <translation>Alçada</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="764"/>
        <source>Depth</source>
        <translation>Fondaria</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="39"/>
        <source>Head(s)</source>
        <translation>Capçal(s)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="630"/>
        <source>Lens</source>
        <translation>Lents</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="636"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="665"/>
        <source>Min Degrees</source>
        <translation>Graus Mínims</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="672"/>
        <source>Max Degrees</source>
        <translation>Graus Màxims</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="79"/>
        <source>Pan Max Degrees</source>
        <translation>Graus Max de Pan</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="96"/>
        <source>Tilt Max Degrees</source>
        <translation>Graus Max de Tilt</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="113"/>
        <source>Layout
(Columns x Rows)</source>
        <translation>Disposició 
(Columnes x Files)</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="158"/>
        <source>Electrical</source>
        <translation>Elèctric</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="164"/>
        <source>Power Consumption</source>
        <translation>Consum elèctric</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="174"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="184"/>
        <source>DMX Connector</source>
        <translation>Connector DMX</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="241"/>
        <source>Copy physical information to clipboard</source>
        <translation>Copiar informació física al porta-retalls</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="258"/>
        <source>Paste physical information from clipboard</source>
        <translation>Enganxar informació física del porta-retalls</translation>
    </message>
</context>
<context>
    <name>FixtureEditor</name>
    <message>
        <location filename="fixtureeditor.ui" line="33"/>
        <source>Fixture</source>
        <translation>Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="43"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="55"/>
        <source>Manufacturer</source>
        <translation>Fabricant</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="68"/>
        <source>The manufacturer name for this fixture (e.g. Martin)</source>
        <translation>El nom del fabricant d&apos;aquest fixture (ej.: Martin)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="75"/>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="88"/>
        <source>The model name for this fixture (e.g. MAC250)</source>
        <translation>El model d&apos;aquest fixture (ej.:MAC250)</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="95"/>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="108"/>
        <source>The general type of this fixture</source>
        <translation>El tipus general d&apos;aquest fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="247"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="254"/>
        <source>The name of the author of this fixture definition</source>
        <translation>Nom del autor d&apos;aquesta definició de fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="298"/>
        <location filename="fixtureeditor.ui" line="498"/>
        <source>Channels</source>
        <translation>Canals</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="320"/>
        <location filename="fixtureeditor.ui" line="493"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="325"/>
        <source>Group</source>
        <translation>Grup</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="333"/>
        <source>Add a channel</source>
        <translation>Afegir un canal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="353"/>
        <source>Remove the selected channel</source>
        <translation>Eliminar el canal seleccionat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="373"/>
        <source>Edit the selected channel</source>
        <translation>Editar el canal seleccionat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="400"/>
        <source>Copy the selected channel to the clipboard</source>
        <translation>Copiar el canal seleccionat al porta-retalls</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="420"/>
        <source>Paste the channel in clipboard to this fixture</source>
        <translation>Enganxar el canal del porta-retalls a aquest fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="453"/>
        <source>Open/close all channel items</source>
        <translation>Obrir/Tancar tots els elements del canal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="474"/>
        <source>Modes</source>
        <translation>Modes</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="503"/>
        <source>Heads</source>
        <translation>Capçals</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="511"/>
        <source>Add a mode</source>
        <translation>Afegir un mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="531"/>
        <source>Remove the selected mode</source>
        <translation>Eliminar el mode seleccionat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="551"/>
        <source>Edit the selected mode</source>
        <translation>Editar el mode seleccionat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="578"/>
        <source>Create a copy of the selected mode</source>
        <translation>Crear una copia del mode seleccionat</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="611"/>
        <source>Open/close all mode items</source>
        <translation>Obrir/Tancar tots els elements de mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="632"/>
        <source>Aliases</source>
        <translation>Alias</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="650"/>
        <source>In mode</source>
        <translation>En mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="667"/>
        <source>Add a new alias</source>
        <translation>Afegeix un àlies nou</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="687"/>
        <source>with</source>
        <translation>Amb</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="694"/>
        <source>replace</source>
        <translation>reemplaça</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="711"/>
        <location filename="fixtureeditor.ui" line="764"/>
        <source>Alias</source>
        <translation>Àlies</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="716"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="721"/>
        <source>Base channel</source>
        <translation>Canal Base</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="726"/>
        <source>Override channel</source>
        <translation>Sobreescriu el canal</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="744"/>
        <source>Remove the currently selected alias</source>
        <translation>Elimina els àlies seleccionats</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="275"/>
        <source>Physical</source>
        <translation>Físic</translation>
    </message>
</context>
<context>
    <name>QLCFixtureEditor</name>
    <message>
        <location filename="fixtureeditor.cpp" line="207"/>
        <source>Close</source>
        <translation>Tancar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="208"/>
        <source>Do you want to save changes to fixture
&quot;%1&quot;
before closing?</source>
        <translation>Vol desar els canvis al fixture
&quot;%1&quot;
abans de tancar?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="237"/>
        <location filename="fixtureeditor.cpp" line="247"/>
        <source>Missing important information</source>
        <translation>Falta informació important</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="238"/>
        <source>Missing manufacturer name.
Unable to save fixture.</source>
        <translation>Falta el nom del fabricant.
No es  pot desar el fixture.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="248"/>
        <source>Missing fixture model name.
Unable to save fixture.</source>
        <translation>Falta el nom del model del fixture.
No es pot desar el fixture.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="278"/>
        <location filename="fixtureeditor.cpp" line="337"/>
        <source>Fixture saving failed</source>
        <translation>Error al desar el fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="279"/>
        <location filename="fixtureeditor.cpp" line="338"/>
        <source>Unable to save fixture definition:
%1</source>
        <translation>Imposible desar les definicions del fixture:
%1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="294"/>
        <source>Save fixture definition</source>
        <translation>Desar la definició del fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="371"/>
        <source>New Fixture</source>
        <translation>Nou Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="448"/>
        <location filename="fixtureeditor.cpp" line="548"/>
        <source>Channel already exists</source>
        <translation>El canal ja existeix</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="449"/>
        <location filename="fixtureeditor.cpp" line="549"/>
        <source>A channel by the name &quot;%1&quot; already exists!</source>
        <translation>Un canal amb el nombre &quot;%1&quot; ja existeix!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="456"/>
        <location filename="fixtureeditor.cpp" line="555"/>
        <source>Channel has no name</source>
        <translation>El canal no te nom</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="457"/>
        <location filename="fixtureeditor.cpp" line="556"/>
        <source>You must give the channel a descriptive name!</source>
        <translation>Te que donar un nom descriptiu al canal!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="494"/>
        <source>Are you sure you wish to remove channel: %1?</source>
        <translation>Esteu segur que vol eliminar el canal: %1 ?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="827"/>
        <source>Are you sure you wish to remove mode: %1?</source>
        <translation>Eteu segur que vol eliminar el mode: %1 ?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="668"/>
        <location filename="fixtureeditor.cpp" line="703"/>
        <location filename="fixtureeditor.cpp" line="928"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="669"/>
        <location filename="fixtureeditor.cpp" line="705"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="670"/>
        <location filename="fixtureeditor.cpp" line="707"/>
        <source>Paste</source>
        <translation>Enganxar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="671"/>
        <location filename="fixtureeditor.cpp" line="709"/>
        <location filename="fixtureeditor.cpp" line="934"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="682"/>
        <source>Channels</source>
        <translation>Canals</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="780"/>
        <location filename="fixtureeditor.cpp" line="789"/>
        <source>Unable to add mode</source>
        <translation>Impossible afegir un mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="781"/>
        <source>Another mode by that name already exists</source>
        <translation>Un altre mode amb aquest nom ja existeix</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="790"/>
        <source>You must give a name to the mode</source>
        <translation>Necessita donar un nom al mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="826"/>
        <source>Remove Mode</source>
        <translation>Eliminar mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="874"/>
        <source>Rename new mode</source>
        <translation>Reanomenar el nou mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="875"/>
        <source>Give a unique name for the mode</source>
        <translation>Trieu un nom únic per el mode</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="877"/>
        <source>Copy of %1</source>
        <translation>Copia de %1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="887"/>
        <source>Invalid name</source>
        <translation>Nom incorrecte</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="888"/>
        <source>Another mode by that name already exists.</source>
        <translation>Un altre mode amb aquest nom ja existeix.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="931"/>
        <source>Clone</source>
        <translation>Clonar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="939"/>
        <source>Modes</source>
        <translation>Modes</translation>
    </message>
</context>
</TS>
